# Copyright (c) 2000-2011, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

%define with()          %{expand:%%{?with_%{1}:1}%%{!?with_%{1}:0}}
%define without()       %{expand:%%{?with_%{1}:0}%%{!?with_%{1}:1}}
%define bcond_with()    %{expand:%%{?_with_%{1}:%%global with_%{1} 1}}
%define bcond_without() %{expand:%%{!?_without_%{1}:%%global with_%{1} 1}}

%bcond_without maven
%bcond_without repolib

%define repodir %{_javadir}/repository.jboss.com/org/jvnet/staxex/%{version}-brew
%define repodirlib %{repodir}/lib
%define repodirsrc %{repodir}/src

%define section free

Name:           stax-ex
Version:        1.2
Release:        11%{?dist}
Epoch:          0
Summary:        STAX extensions
Group:          Development/Libraries/Java
License:        CDDL
URL:            https://stax-ex.dev.java.net/
# cvs -d :pserver:guest@cvs.dev.java.net:/cvs login
# cvs -d :pserver:guest@cvs.dev.java.net:/cvs export -r stax-ex-1_2 -d stax-ex-1.2 stax-ex
# tar czf stax-ex-1.2.tar.gz stax-ex-1.2
Source0:        stax-ex-1.2.tar.gz
Source1:        stax-ex-settings.xml
Source2:        stax-ex-1.2-autogenerated-files.tar.gz
Source3:        stax-ex-jpp-depmap.xml
Source4:        stax-ex-component-info.xml
Patch0:         stax-ex-pom.patch
Requires(post): jpackage-utils
Requires(postun): jpackage-utils
Requires:       java >= 0:1.5.0
Requires:       jaf_1_1_api
Requires:       jpackage-utils
Requires:       stax_1_0_api
BuildRequires:  ant >= 0:1.6.5
BuildRequires:  ant-junit
BuildRequires:  java-devel >= 0:1.5.0
BuildRequires:  javatools-package-rename-task
BuildRequires:  jpackage-utils
BuildRequires:  junit
BuildRequires:  jaf_1_1_api
BuildRequires:  stax_1_0_api
%if %with maven
BuildRequires:  maven2 >= 0:2.0.7
BuildRequires:  maven-doxia-sitetools
BuildRequires:  maven2-plugin-ant
BuildRequires:  maven2-plugin-compiler
BuildRequires:  maven2-plugin-deploy
BuildRequires:  maven2-plugin-install
BuildRequires:  maven2-plugin-jar
BuildRequires:  maven2-plugin-javadoc
BuildRequires:  maven2-plugin-resources
BuildRequires:  maven2-plugin-surefire
%endif
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root

%description
This project develops a few extensions to complement JSR-173
StAX API in the following area.
1. Enable parser instance reuse (which is important in the 
   high-performance environment like JAXB and JAX-WS)
2. Improve the support for reading from non-text XML infoset, 
   such as FastInfoset.
3. Improve the namespace support. 

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Documentation
Requires:       jpackage-utils

%description javadoc
%{summary}.

%if %with repolib
%package repolib
Summary:        Artifacts to be uploaded to a repository library
Group:          Development/Libraries/Java

%description repolib
Artifacts to be uploaded to a repository library.
This package is not meant to be installed but so its contents
can be extracted through rpm2cpio.
%endif

%prep
%setup -q 
%if %without maven
%setup -q -T -D -a 2
%endif
%{_bindir}/find -type f -name "*.jar" | %{_bindir}/xargs -t %{__rm}
%patch0 -p0 -b .sav0

%{__cp} -p %{SOURCE1} settings.xml
%{__sed} -i -e "s|<url>__JPP_URL_PLACEHOLDER__</url>|<url>file://$(pwd)/m2_repo/repository</url>|g" settings.xml
%{__sed} -i -e "s|<url>__JAVADIR_PLACEHOLDER__</url>|<url>file://$(pwd)/external_repo</url>|g" settings.xml
%{__sed} -i -e "s|<url>__MAVENREPO_DIR_PLACEHOLDER__</url>|<url>file://$(pwd)/m2_repo/repository</url>|g" settings.xml

%{__mkdir} external_repo
%{__ln_s} %{_javadir} external_repo/JPP

%build
cd stax-ex

%if %with maven
export MAVEN_REPO_LOCAL=$(pwd)/m2_repo/repository
mkdir -p ${MAVEN_REPO_LOCAL}
export M2_SETTINGS=$(pwd)/settings.xml
%{_bindir}/mvn-jpp -e \
        -s $(pwd)/settings.xml \
        -Dmaven2.jpp.mode=true \
        -Dmaven2.jpp.depmap.file=%{SOURCE3} \
        -Dmaven.repo.local=${MAVEN_REPO_LOCAL} \
        -DaltDeploymentRepository=oss-releases::default::file:../maven2-brew \
        ant:ant deploy javadoc:javadoc
%else
export OPT_JAR_LIST=`%{__cat} %{_sysconfdir}/ant.d/junit`
export CLASSPATH=$(%{_bindir}/build-classpath jaf_1_1_api stax_1_0_api)
%{ant} -Dmaven.settings.offline=true -Dbuild.sysclasspath=only jar javadoc
%endif

%install
%{__rm} -rf %{buildroot}

%{__mkdir_p} %{buildroot}%{_javadir}
%{__cp} -p stax-ex/target/stax-ex-%{version}.jar %{buildroot}%{_javadir}/%{name}-%{version}.jar
%{__ln_s} %{name}-%{version}.jar %{buildroot}%{_javadir}/%{name}.jar

%{__mkdir_p} %{buildroot}%{_datadir}/maven2/poms
%{__cp} -p stax-ex/pom.xml %{buildroot}%{_datadir}/maven2/poms/JPP-%{name}.pom
%add_to_maven_depmap org.jvnet.staxex stax-ex %{version} JPP %{name}

%{__mkdir_p} %{buildroot}%{_javadocdir}/%{name}-%{version}
%{__cp} -pr stax-ex/target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}-%{version}
%{__ln_s} %{name}-%{version} %{buildroot}%{_javadocdir}/%{name}

%if %with repolib
%{__mkdir_p} %{buildroot}%{_javadir}/repository.jboss.com
%{__cp} -pr maven2-brew %{buildroot}%{_javadir}/repository.jboss.com

%{__mkdir_p} %{buildroot}%{repodir}
%{__mkdir_p} %{buildroot}%{repodirlib}
%{__cp} -p %{SOURCE4} %{buildroot}%{repodir}/component-info.xml
tag=`/bin/echo %{name}-%{version}-%{release} | %{__sed} 's|\.|_|g'`
%{__sed} -i "s/@TAG@/$tag/g" %{buildroot}%{repodir}/component-info.xml
%{__sed} -i "s/@VERSION@/%{version}-brew/g" %{buildroot}%{repodir}/component-info.xml
%{__mkdir_p} %{buildroot}%{repodirsrc}
%{__cp} -p %{SOURCE0} %{buildroot}%{repodirsrc}
%{__cp} -p %{SOURCE1} %{buildroot}%{repodirsrc}
%{__cp} -p %{SOURCE2} %{buildroot}%{repodirsrc}
%{__cp} -p %{SOURCE3} %{buildroot}%{repodirsrc}
%{__cp} -p %{PATCH0} %{buildroot}%{repodirsrc}
%{__cp} -p %{buildroot}%{_javadir}/%{name}-%{version}.jar %{buildroot}%{repodirlib}/stax-ex.jar
%{__cp} -p %{buildroot}%{_datadir}/maven2/poms/JPP-%{name}.pom %{buildroot}%{repodirlib}/stax-ex.pom
%endif

%clean
%{__rm} -rf %{buildroot}

%post
%update_maven_depmap

%postun
%update_maven_depmap

%files
%defattr(0644,root,root,0755)
%doc stax-ex/LICENSE.txt
%{_javadir}*/%{name}-%{version}.jar
%{_javadir}*/%{name}.jar
%{_datadir}/maven2/poms/JPP-%{name}.pom
%{_mavendepmapfragdir}/%{name}

%files javadoc
%defattr(0644,root,root,0755)
%{_javadocdir}/%{name}-%{version}
%{_javadocdir}/%{name}

%if %with repolib
%files repolib
%defattr(0644,root,root,0755)
%dir %{_javadir}*
%exclude %dir %{_javadocdir}
%{_javadir}*/repository.jboss.com
%endif

%changelog
* Fri Mar 11 2011 David Walluck <dwalluck@redhat.com> 0:1.2-11
- copy MEAD repo

* Mon Feb 07 2011 David Walluck <dwalluck@redhat.com> 0:1.2-10
- change back to to stax_1_0_api
- fix repolib

* Fri Dec 10 2010 Hui Wang <huwang@redhat.com> - 0:1.2-9
- Change BR/R stax_1_0_api to codehaus-stax-api
- Add upload.sh and content of maven2-brew to repolib
- Fix %%files for signed jars

* Wed Sep 08 2010 David Walluck <dwalluck@redhat.com> 0:1.2-8
- fix Found Banned Dependency: javax.xml.stream:stax-api:jar:1.0

* Fri May 07 2010 Martha Benitez <mbenitez@redhat.com> - 0:1.2-7.1
- rebuilt

* Tue Apr 06 2010 Hui Wang <huwang@redhat.com> 0:1.2-7
- Rebuild

* Mon Jul 20 2009 David Walluck <dwalluck@redhat.com> 0:1.2-6
- fix repolib

* Tue Feb 10 2009 David Walluck <dwalluck@redhat.com> 0:1.2-5
- add repolib

* Mon Dec 08 2008 Will Tatam <will.tatam@red61.com> 1.2-4
- Auto rebuild for JPackage 5 in mock

* Fri Oct 10 2008 David Walluck <dwalluck@redhat.com> 0:1.2-3
- fix changelog

* Fri Oct 10 2008 David Walluck <dwalluck@redhat.com> 0:1.2-2
- build for JPackage 5

* Wed Apr 09 2008 Ralph Apel <r.apel at r-apel.de> - 0:1.2-1jpp
- 1.2

* Tue Mar 11 2008 Ralph Apel <r.apel at r-apel.de> - 0:1.0-1jpp
- First release
